Enum uiua::Value

source ·
#[repr(C)]
pub enum Value { Num(Array<f64>), Byte(Array<u8>), Complex(Array<Complex>), Char(Array<char>), Box(Array<Boxed>), }
A generic array value

This enum is used to represent all possible array types.

Variants



Num(Array<f64>)

Common number array



Byte(Array<u8>)

Byte array used for some boolean operations and for I/O



Complex(Array<Complex>)

Complex number array



Char(Array<char>)

Common character array



Box(Array<Boxed>)

Common box array

Implementations

source

impl Value

source

pub fn join(self, other: Self, env: &Uiua) -> UiuaResult<Self>

join the array with another

source

pub fn join_infallible(self, other: Self) -> Self

join the array with another

Panics

Panics if the arrays have incompatible shapes

source

impl Value

source

pub fn couple(self, other: Self, env: &Uiua) -> UiuaResult<Self>

couple the value with another

source

pub fn couple_infallible(self, other: Self) -> Self

couple the value with another

Panics

Panics if the values have incompatible shapes

source

pub fn uncouple(self, env: &Uiua) -> UiuaResult<(Self, Self)>

Uncouple the value into two values

source

impl Value

source

pub fn from_row_values_infallible<V>(values: V) -> Self

Create a value from row values

Panics

Panics if the row values have incompatible shapes

source

pub fn from_row_values<V, C>(values: V, ctx: &C) -> Result<Self, C::Error>
where V: IntoIterator<Item = Value>, V::IntoIter: ExactSizeIterator, C: FillContext,

Create a value from row values

source

impl Value

source

pub fn pick(self, from: Self, env: &Uiua) -> UiuaResult<Self>

Use this array as an index to pick from another

source

impl Value

source

pub fn take(self, from: Self, env: &Uiua) -> UiuaResult<Self>

Use this value to take from another

source

pub fn drop(self, from: Self, env: &Uiua) -> UiuaResult<Self>

Use this value to drop from another

source

impl Value

source

pub fn select(&self, from: &Self, env: &Uiua) -> UiuaResult<Self>

Use this value to select from another

source

impl Value

source

pub fn reshape(&mut self, shape: &Self, env: &Uiua) -> UiuaResult

reshape this value with another

source

impl Value

source

pub fn rerank(&mut self, rank: &Self, env: &Uiua) -> UiuaResult

rerank this value with another

source

impl Value

source

pub fn keep(&self, kept: Self, env: &Uiua) -> UiuaResult<Self>

Use this value as counts to keep another

source

impl Value

source

pub fn rotate(&self, rotated: Self, env: &Uiua) -> UiuaResult<Self>

Use this value to rotate another

source

impl Value

source

pub fn windows(&self, from: &Self, env: &Uiua) -> UiuaResult<Self>

Use this array to windows another

source

impl Value

source

pub fn find(&self, searched: &Self, env: &Uiua) -> UiuaResult<Self>

Try to find this value in another

source

impl Value

source

pub fn member(&self, of: &Self, env: &Uiua) -> UiuaResult<Self>

Check which rows of this value are members of another

source

impl Value

source

pub fn index_of(&self, searched_in: &Value, env: &Uiua) -> UiuaResult<Value>

Get the index of the rows of this value in another

source

pub fn progressive_index_of( &self, searched_in: &Value, env: &Uiua ) -> UiuaResult<Value>

Get the progressive index of the rows of this value in another

source

impl Value

source

pub fn map(self, values: Self, env: &Uiua) -> UiuaResult<Value>

Create a map array

source

pub fn unmap(self, env: &Uiua) -> UiuaResult<(Value, Value)>

Turn a map array into its keys and values

source

pub fn get(&self, key: &Value, env: &Uiua) -> UiuaResult<Value>

Get a value from a map array

source

pub fn has_key(&self, key: &Value, env: &Uiua) -> UiuaResult<bool>

Check if a map array contains a key

source

pub fn insert(&mut self, key: Value, value: Value, env: &Uiua) -> UiuaResult

Insert a key-value pair into a map array

source

pub fn remove(&mut self, key: Value, env: &Uiua) -> UiuaResult

Remove a key-value pair from a map array

source

impl Value

source

pub fn deshape(&mut self)

Make the value 1-dimensional

source

pub fn fix(&mut self)

Add a 1-length dimension to the front of the value’s shape

source

pub fn parse_num(&self, env: &Uiua) -> UiuaResult<Self>

Attempt to parse the value into a number

source

pub fn representation(&self) -> Self

Convert value into a string that can be understood by the interpreter

source

impl Value

source

pub fn range(&self, env: &Uiua) -> UiuaResult<Self>

Create a range array

source

impl Value

source

pub fn first(self, env: &Uiua) -> UiuaResult<Self>

Get the first row of the value

source

pub fn last(self, env: &Uiua) -> UiuaResult<Self>

Get the last row of the value

source

impl Value

source

pub fn reverse(&mut self)

Reverse the rows of the value

source

impl Value

source

pub fn transpose(&mut self)

Transpose the value

source

impl Value

source

pub fn rise(&self, env: &Uiua) -> UiuaResult<Vec<usize>>

Get the rise of the value

source

pub fn fall(&self, env: &Uiua) -> UiuaResult<Vec<usize>>

Get the fall of the value

source

pub fn sort_up(&mut self, env: &Uiua) -> UiuaResult

Sort the value ascending

source

pub fn sort_down(&mut self, env: &Uiua) -> UiuaResult

Sort the value descending

source

pub fn classify(&self) -> Self

classify the rows of the value

source

pub fn deduplicate(&mut self)

deduplicate the rows of the value

source

pub fn unique(&self) -> Self

Mask the unique rows of the value

source

impl Value

source

pub fn bits(&self, env: &Uiua) -> UiuaResult<Array<u8>>

Encode the bits of the value

source

pub fn inv_bits(&self, env: &Uiua) -> UiuaResult<Array<f64>>

Decode the bits of the value

source

impl Value

source

pub fn wher(&self, env: &Uiua) -> UiuaResult<Array<f64>>

Get the indices where the value is nonzero

source

pub fn first_where(&self, env: &Uiua) -> UiuaResult<Array<f64>>

Get the first index where the value is nonzero

source

pub fn inv_where(&self, env: &Uiua) -> UiuaResult<Self>

un where

source

impl Value

source

pub fn utf8(&self, env: &Uiua) -> UiuaResult<Self>

Convert a string value to a list of UTF-8 bytes

source

pub fn inv_utf8(&self, env: &Uiua) -> UiuaResult<Self>

Convert a list of UTF-8 bytes to a string value

source

impl Value

source

pub fn as_num_array(&self) -> Option<&Array<f64>>

Get a reference to a possible number array

source

pub fn as_byte_array(&self) -> Option<&Array<u8>>

Get a reference to a possible byte array

source

pub fn as_char_array(&self) -> Option<&Array<char>>

Get a reference to a possible character array

source

pub fn as_box_array(&self) -> Option<&Array<Boxed>>

Get a reference to a possible box array

source

pub fn as_box(&self) -> Option<&Boxed>

Get a reference to a possible scalar box

source

pub fn rows(&self) -> Box<dyn ExactSizeIterator<Item = Self> + '_>

Get an iterator over the rows of the value

source

pub fn row_shaped_slices( &self, row_shape: Shape ) -> Box<dyn ExactSizeIterator<Item = Self> + '_>

Get an iterator over the rows of the value that have the given shape

source

pub fn into_row_shaped_slices( self, row_shape: Shape ) -> Box<dyn DoubleEndedIterator<Item = Self>>

Get an iterator over the rows of the value that have the given shape

source

pub fn into_rows(self) -> Box<dyn ExactDoubleIterator<Item = Self>>

Consume the value and get an iterator over its rows

source

pub fn into_elements(self) -> Box<dyn Iterator<Item = Self>>

Cosume the value and get an iterator over its elements

source

pub fn type_name(&self) -> &'static str

Get the value’s type name

source

pub fn type_name_plural(&self) -> &'static str

Get a plural form of the value’s type name

source

pub fn row_count(&self) -> usize

Get the number of rows

source

pub fn row_len(&self) -> usize

Get the number of element in each row

source

pub fn rank(&self) -> usize

Get the rank

source

impl Value

source

pub fn shape(&self) -> &Shape

Get the shape of the value

source

pub fn shape_mut(&mut self) -> &mut Shape

Get a mutable reference to the shape

source

pub fn element_count(&self) -> usize

Get the number of elements

source

pub fn meta(&self) -> &ArrayMeta

Get the value’s metadata

source

pub fn meta_mut(&mut self) -> &mut ArrayMeta

Get a mutable reference to the value’s metadata

source

pub fn take_label(&mut self) -> Option<EcoString>

Take the label from the value

source

pub fn combine_meta(&mut self, other: &ArrayMeta)

Combine this value’s metadata with another

source

pub fn reset_meta(&mut self)

Reset this value’s metadata

source

pub fn reset_meta_flags(&mut self)

Reset this value’s metadata flags

source

pub fn row(&self, i: usize) -> Self

Get the row at the given index

source

pub fn show(&self) -> String

Get the pretty-printed string representation of the value that appears in output

source

pub fn format(&self) -> String

Get the pretty-printed string representation of the value that appears when formatted

source

pub fn as_ints( &self, env: &Uiua, requirement: &'static str ) -> UiuaResult<Vec<isize>>

Attempt to convert the array to a list of integers

The requirement parameter is used in error messages.

source

pub fn as_bool(&self, env: &Uiua, requirement: &'static str) -> UiuaResult<bool>

Attempt to convert the array to a single boolean

The requirement parameter is used in error messages.

source

pub fn as_nat(&self, env: &Uiua, requirement: &'static str) -> UiuaResult<usize>

Attempt to convert the array to a single natural number

The requirement parameter is used in error messages.

source

pub fn as_int(&self, env: &Uiua, requirement: &'static str) -> UiuaResult<isize>

Attempt to convert the array to a single integer

The requirement parameter is used in error messages.

source

pub fn as_num(&self, env: &Uiua, requirement: &'static str) -> UiuaResult<f64>

Attempt to convert the array to a single number

The requirement parameter is used in error messages.

source

pub fn as_nums( &self, env: &Uiua, requirement: &'static str ) -> UiuaResult<Vec<f64>>

Attempt to convert the array to a list of numbers

The requirement parameter is used in error messages.

source

pub fn as_nats( &self, env: &Uiua, requirement: &'static str ) -> UiuaResult<Vec<usize>>

Attempt to convert the array to a list of natural numbers

The requirement parameter is used in error messages.

source

pub fn as_bytes( &self, env: &Uiua, requirement: &'static str ) -> UiuaResult<Vec<u8>>

Attempt to convert the array to a list of bytes

The requirement parameter is used in error messages.

source

pub fn as_rank_list( &self, env: &Uiua, requirement: &'static str ) -> UiuaResult<Vec<Option<isize>>>

Attempt to convert the array to a list of integers or infinity

None represents infinity.

The requirement parameter is used in error messages.

source

pub fn as_string( &self, env: &Uiua, requirement: &'static str ) -> UiuaResult<String>

Attempt to convert the array to a string

The requirement parameter is used in error messages.

source

pub fn into_bytes( self, env: &Uiua, requirement: &'static str ) -> UiuaResult<Vec<u8>>

Attempt to convert the array to a list of bytes

The requirement parameter is used in error messages.

source

pub fn unpack(&mut self)

Remove all top-level layers of boxing

source

pub fn unpacked(self) -> Self

Remove all top-level layers of boxing

source

pub fn map_boxed(self, f: impl FnOnce(Self) -> Self) -> Self

Apply a function to the highest-level unboxed value

source

pub fn try_map_boxed( self, f: impl FnOnce(Self) -> UiuaResult<Self> ) -> UiuaResult<Self>

Apply a function to the highest-level unboxed value

source

pub fn unbox(&mut self)

Remove a single layer of boxing

source

pub fn unboxed(self) -> Self

Remove a single layer of boxing

source

pub fn box_if_not(&mut self)

Turn the value into a scalar box if it is not one already

source

pub fn boxed_if_not(self) -> Boxed

Turn the value into a scalar box if it is not one already

source

pub fn compress(&mut self)

Turn a number array into a byte array if no information is lost.

Does nothing without the bytes feature enabled.

source

pub fn coerce_to_boxes(self) -> Array<Boxed>

Convert to a box array by boxing every element

source

pub fn coerce_as_boxes(&self) -> Cow<'_, Array<Boxed>>

Convert to a box array by boxing every element

source

pub fn keep_label( self, f: impl FnOnce(Self) -> UiuaResult<Self> ) -> UiuaResult<Self>

Propogate a value’s label accross an operation

source

pub fn keep_labels( self, other: Self, f: impl FnOnce(Self, Self) -> UiuaResult<Self> ) -> UiuaResult<Self>

Propogate values’ labels accross an operation