Struct uiua::Complex

source ·
pub struct Complex {
    pub re: f64,
    pub im: f64,
}
Uiua’s complex number type

Fields

re: f64

The real part

im: f64

The imaginary part

Implementations

source

impl Complex

source

pub const ZERO: Self = _

The complex number 0 + 0i

source

pub const ONE: Self = _

The complex number 1 + 0i

source

pub const I: Self = _

The complex number 0 + 1i

source

pub fn new(re: f64, im: f64) -> Self

Create a new complex number

source

pub fn min(self, rhs: impl Into<Self>) -> Self

Get the minimum of the real and imaginary parts of two complex numbers, ignoring NaN

source

pub fn max(self, rhs: impl Into<Self>) -> Self

Get the maximum of the real and imaginary parts of two complex numbers, ignoring NaN

source

pub fn floor(self) -> Self

Get the floor of the real and imaginary parts of a complex number

source

pub fn ceil(self) -> Self

Get the ceiling of the real and imaginary parts of a complex number

source

pub fn round(self) -> Self

Round the real and imaginary parts of a complex number

source

pub fn abs(self) -> f64

Get the absolute value of a complex number

source

pub fn atan2(self, x: impl Into<Self>) -> Complex

Get the arctangent of a complex number

source

pub fn normalize(self) -> Self

Normalize a complex number

source

pub fn arg(self) -> f64

Calculate the principal value of the complex number

source

pub fn to_polar(self) -> (f64, f64)

Convert a complex number to polar coordinates

source

pub fn from_polar(r: f64, theta: f64) -> Self

Convert polar coordinates to a complex number

source

pub fn powc(self, power: impl Into<Self>) -> Self

Raise a complex number to a complex power

source

pub fn powf(self, power: f64) -> Self

Raise a complex number to a real power

source

pub fn exp(self) -> Self

Calculate the exponential of a complex number

source

pub fn ln(self) -> Self

Calculate the natural logarithm of a complex number

source

pub fn log(self, base: impl Into<Self>) -> Self

Calculate the logarithm of a complex number

source

pub fn sqrt(self) -> Self

Calculate the square root of a complex number

source

pub fn sin(self) -> Self

Calculate the sine of a complex number

source

pub fn cos(self) -> Self

Calculate the cosine of a complex number

source

pub fn asin(self) -> Self

Calculate the arc sine of a complex number

source

pub fn acos(self) -> Self

Calculate the arc cosine of a complex number