Struct uiua::Report

source ·
pub struct Report {
    pub kind: ReportKind,
    pub fragments: Vec<ReportFragment>,
    pub color: bool,
}
A rich-text error/diagnostic report

Fields

kind: ReportKind

What kind of report this is

fragments: Vec<ReportFragment>

The rich-text fragments of the report

color: bool

Whether to color the report with ANSI escape codes when converting it to a string

Defaults to true

Implementations

source

impl Report

source

pub fn color(self, color: bool) -> Self

Change whether to color the report with ANSI escape codes when converting it to a string

Defaults to true

source

pub fn trace(self, trace: &[TraceFrame]) -> Self

Add a trace to the report

source

pub fn new(kind: ReportKind, message: impl Into<String>) -> Self

Create a new report

source

pub fn new_multi<I, T>(kind: ReportKind, inputs: &Inputs, errors: I) -> Self
where I: IntoIterator<Item = (T, Span)>, T: Display,

Create a new report with multiple messages