Signature

Struct Signature 

pub struct Signature { /* private fields */ }
A function stack signature

Implementations

Source

impl Signature

pub const fn new(args: usize, outputs: usize) -> Signature

Create a new signature with the given number of arguments and outputs

pub fn with_under(self, under_args: usize, under_outputs: usize) -> Signature

Set the number of arguments and outputs of the under stack

pub const fn args(&self) -> usize

Get the number of arguments

pub const fn outputs(&self) -> usize

Get the number of outputs

pub const fn under_args(&self) -> usize

Get the number of under arguments

pub const fn under_outputs(&self) -> usize

Get the number of under outputs

pub const fn set_args(&mut self, args: usize)

Set the number of arguments

pub const fn set_outputs(&mut self, outputs: usize)

Set the number of outputs

pub fn update_args(&mut self, f: impl FnOnce(usize) -> usize)

Update the number of arguments

pub fn update_outputs(&mut self, f: impl FnOnce(usize) -> usize)

Update the number of outputs

pub fn update_under_args(&mut self, f: impl FnOnce(usize) -> usize)

Update the number of under arguments

pub fn update_under_outputs(&mut self, f: impl FnOnce(usize) -> usize)

Update the number of under outputs

pub fn update_args_outputs( &mut self, f: impl FnOnce(usize, usize) -> (usize, usize), )

Update the number of arguments and outputs

pub fn is_compatible_with(self, other: Signature) -> bool

Check if this signature changes the stack size by the same amount as another signature

pub fn is_superset_of(self, other: Signature) -> bool

Check if this Signature::is_compatible_with another signature and has at least as many arguments

pub fn is_subset_of(self, other: Signature) -> bool

Check if this Signature::is_compatible_with another signature and has at most as many arguments

pub fn max_with(self, other: Signature) -> Signature

Get the signature that has the maximum of the arguments and outputs of this signature and another

pub fn compose(self, other: Signature) -> Signature

Compose signatures as if a function with signature other was called before a function with signature self

pub fn inverse(self) -> Signature

Get the un-inverse of this signature

pub fn anti(self) -> Option<Signature>

The anti-inverse of this signature

pub fn under(self) -> Signature

The signature on the under stack