pub struct Complex {
pub re: f64,
pub im: f64,
}Expand description
Uiua’s complex number type
Fields
re: f64The real part
im: f64The imaginary part
Implementations
sourceimpl Complex
impl Complex
sourcepub fn min(self, rhs: impl Into<Self>) -> Self
pub fn min(self, rhs: impl Into<Self>) -> Self
Get the minimum of the real and imaginary parts of two complex numbers, ignoring NaN
sourcepub fn max(self, rhs: impl Into<Self>) -> Self
pub fn max(self, rhs: impl Into<Self>) -> Self
Get the maximum of the real and imaginary parts of two complex numbers, ignoring NaN
sourcepub fn from_polar(r: f64, theta: f64) -> Self
pub fn from_polar(r: f64, theta: f64) -> Self
Convert polar coordinates to a complex number